# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`dokuwiki`](#dokuwiki): This module manages and install dokuwiki.
* [`dokuwiki::config`](#dokuwikiconfig): Main configuration of dokuwiki
* [`dokuwiki::install`](#dokuwikiinstall): Main installation of dokuwiki
* [`dokuwiki::params`](#dokuwikiparams): Default variable logic for dokuwiki
* [`dokuwiki::service`](#dokuwikiservice): Configures services required by dokuwiki

**Defined types**

* [`dokuwiki::acl`](#dokuwikiacl): Create ACL rules in the acl.auth.php configuration file
* [`dokuwiki::user`](#dokuwikiuser): Creates local user in the users.auth.php file

## Classes

### dokuwiki

dokuwiki

This module manages and install dokuwiki.

#### Examples

##### 

```puppet
class { 'dokuwiki':
  wiki_title => 'My awesome dokuwiki'
}
```

#### Parameters

The following parameters are available in the `dokuwiki` class.

##### `wiki_title`

Data type: `String`

The title of this wiki, will be displayed on all the pages.

##### `admin_user`

Data type: `String`

The username of the admin user, can be left empty if default_acl is open

Default value: $dokuwiki::params::admin_user

##### `admin_passwordhash`

Data type: `String`

The password hash of the admin user.
To generate the hash use the mkpasswd, which is part of the whois package.
Generate the password using the following command: ```mkpasswd -m sha-512 -s <<< YourPass```

Default value: $dokuwiki::params::admin_password

##### `admin_real_name`

Data type: `String`

The real name of the admin user

Default value: $dokuwiki::params::admin_real_name

##### `admin_email`

Data type: `String`

The e-mail adres of the admin user

Default value: $dokuwiki::params::admin_email

##### `admin_groups`

Data type: `Array`

An array of group for the admin user.

Default value: $dokuwiki::params::admin_groups

##### `manage_webserver`

Data type: `Boolean`

If enabled (default), this module will also manages and installs apache

Default value: $dokuwiki::params::manage_webserver

##### `manage_php`

Data type: `Boolean`

If enabled (default), this module also manages and installs php

Default value: $dokuwiki::params::manage_php

##### `enable_ssl`

Data type: `Boolean`

If enabled, this module will enable ssl and also a redirect to port 443 from port 80

Default value: $dokuwiki::params::enable_ssl

##### `servername`

Data type: `String`

Default set to the fqdn fact is used for the redirect of port 80 to port 443.
Make sure this name is resolve able by the clients accessing the server.

Default value: $dokuwiki::params::servername

##### `ssl_cert`

Data type: `String`

Defaults to the selfsigned snakeoil certificate, but can be used to change
the certificate used by the apache instance

Default value: $dokuwiki::params::ssl_cert

##### `ssl_key`

Data type: `String`

Defaults to the selfsigned snakeoil private key, but can be used to change the
privatekey used by the apache instance

Default value: $dokuwiki::params::ssl_key

##### `ssl_chain`

Data type: `Optional[String]`

Defaults to undef, but can be used to specify the cachain that apache will sent.

Default value: $dokuwiki::params::ssl_chain

##### `lang`

Data type: `String`

The language of the dokuwiki

Default value: $dokuwiki::params::lang

##### `license`

Data type: `String`

The default license used for all the content placed on the dokuwiki

Default value: $dokuwiki::params::license

##### `useacl`

Data type: `Integer`

If set to 1 the ACL module is enable and the dokuwiki will use the acl.auth.php config file

Default value: $dokuwiki::params::useacl

##### `default_acl`

Data type: `Enum['public', 'open', 'closed']`

Specifiy the default acl.
Open means: anyone can edit, Public means: anyone can view; users can edit, Closed means: only users can view and edit

Default value: $dokuwiki::params::default_acl

##### `replace_acl`

Data type: `Boolean`

If set, this module will replace contents of the ACL, possibly revering changes done in the webinterface.
Dokuwiki does not recommend this.

Default value: $dokuwiki::params::replace_acl

##### `replace_local`

Data type: `Boolean`

If set (default unset), this module will replace contents of the local.php file, possibly reverting
changes done in the webinterface.

Default value: $dokuwiki::params::replace_local

##### `replace_users_auth`

Data type: `Boolean`

If set, this module will replace contents in the users.auth.php file, possibly reverting changes
done in the webitnerface.

Default value: $dokuwiki::params::replace_users_auth

##### `superuser`

Data type: `String`

This variable determines which user or group defines the super admins

Default value: $dokuwiki::params::superuser

##### `disableactions`

Data type: `String`

This variable can be used to disable specific actions: like registering.
See https://www.dokuwiki.org/config:disableactions for more information

Default value: $dokuwiki::params::disableactions

##### `userewrite`

Data type: `Integer[0, 2]`

The variable can be used to enable rewrites. Defaults to 0.

Default value: $dokuwiki::params::userewrite

### dokuwiki::config

dokuwiki::config

Main configuration of dokuwiki

#### Examples

##### 

```puppet
This class should not be called
```

### dokuwiki::install

dokuwiki::install

Main installation of dokuwiki

#### Examples

##### 

```puppet
This class should not be called
```

### dokuwiki::params

dokuwiki::params

Default variable logic for dokuwiki

#### Examples

##### 

```puppet
This class should not be called
```

### dokuwiki::service

dokuwiki::service

Configures services required by dokuwiki

#### Examples

##### 

```puppet
This class should not be called
```

## Defined types

### dokuwiki::acl

dokuwiki::acl

Create ACL rules in the acl.auth.php configuration file

#### Examples

##### 

```puppet
dokuwiki::acl { 'acl_line':
  namespace  => '*',
  group      => '@ALL',
  permission => '8',
}
```

#### Parameters

The following parameters are available in the `dokuwiki::acl` defined type.

##### `namespace`

Data type: `String`

Specify the name for which this ACL rule applies. Use '*' to apply rule to all namespaces.

##### `group`

Data type: `String`

Specify the group for which this ACL rule applies.
Start the group name with the '@' sign and use '*' to apply rule to all groups.

##### `permission`

Data type: `Numeric`

Specify the permission for this ACL rule.
Possible permissions are: 1 for read, 2 edit, 4 create, 8 upload. See https://www.dokuwiki.org/acl for more information.

### dokuwiki::user

dokuwiki::user

Creates local user in the users.auth.php file

#### Examples

##### 

```puppet
dokuwiki::user { 'admin':
  passwordhash => '$1$4fd0ad31$.cId7p1uxI4a.RcrH81On0',
  real_name    => 'admin',
  email        => 'root@localhost',
  groups       => ['user', 'admin'],
}
```

#### Parameters

The following parameters are available in the `dokuwiki::user` defined type.

##### `passwordhash`

Data type: `String`

The password hash for the user. To generate the hash use the mkpasswd, which is part of the whois package.
Generate the password using the following command:
``` mkpasswd -m sha-512 -s <<< YourPass ```

Default value: ''

##### `real_name`

Data type: `String`

The real name of the user, used to display the name of the user when pages are edit or created.

Default value: ''

##### `email`

Data type: `String`

The e-mail address of the user.

Default value: ''

##### `groups`

Data type: `Array`

The groups of the user.

Default value: []

##### `login`

Data type: `String`

The username of the user to create, default to the $name parameter.

Default value: $name

